// src/AuthenticationProvider.tsx
import React2 from "react";
import { InteractionType } from "@azure/msal-browser";
import { AuthenticatedTemplate, MsalAuthenticationTemplate, MsalProvider, UnauthenticatedTemplate } from "@azure/msal-react";

// src/hooks/useConfiguration.ts
import { useEffect, useState } from "react";
import { BrowserCacheLocation, PublicClientApplication } from "@azure/msal-browser";

// src/configs/index.ts
var environmentConfig = () => ({
  clientId: getEnvironmentValue("MSAL_CLIENT_ID"),
  authority: getEnvironmentValue("MSAL_AUTHORITY"),
  loginRedirectUri: getEnvironmentValue("MSAL_REDIRECT_URL"),
  logoutRedirectUri: getEnvironmentValue("MSAL_LOGOUT_REDIRECT_URL"),
  scopes: getEnvironmentValue("MSAL_SCOPES"),
  cacheLoc: getEnvironmentValue("MSAL_CACHE_LOCATION"),
  tokenInterval: getEnvironmentValue("MSAL_TOKEN_INTERVAL"),
  tokenThreshold: getEnvironmentValue("MSAL_TOKEN_REFRESH_THRESHOLD")
});
var getEnvironmentValue = (key) => {
  if (key === void 0 || key === null) {
    throw new Error(`${key} not exists in the .env file`);
  }
  return process.env[`VITE_${key}`];
};
var Constants = {
  SPLIT_COMMA: ",",
  TOKEN_INTERVAL: 36e5,
  TOKEN_THRESHOLD: 300,
  SCOPES: ["User.Read"],
  MIDDLEWARE_URL: "_MIDDLEWARE_URL",
  MIDDLEWARE_KEY: "_MIDDLEWARE_KEY"
};
var ConstantsMessage = {
  MSG_ENV: "Missing environment configuration",
  MSG_CLIENT_ID: "Missing clientId",
  MSG_AUTH_URL: "Missing authority url",
  MSG_REDIRECT_URL: "Missing redirect url"
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [config, setConfig] = useState();
  const [options, setOptions] = useState();
  useEffect(() => {
    if (authConfig != null && authConfig.option) {
      setOptions(authConfig.option);
    }
    const clientInstance = authConfig && authConfig.instance ? authConfig.instance : defaultInstance();
    const msalInstance = new PublicClientApplication(clientInstance);
    if (msalInstance) {
      setConfig(msalInstance);
    }
  }, [authConfig]);
  const defaultInstance = () => {
    const env = environmentConfig();
    if (!env)
      throw new Error(ConstantsMessage.MSG_ENV);
    let interval = Constants.TOKEN_INTERVAL;
    let threshold = Constants.TOKEN_THRESHOLD;
    let cacheLoc = BrowserCacheLocation.LocalStorage;
    if (!env.clientId) {
      throw new Error(ConstantsMessage.MSG_CLIENT_ID);
    }
    if (!env.authority) {
      throw new Error(ConstantsMessage.MSG_AUTH_URL);
    }
    if (!env.loginRedirectUri) {
      throw new Error(ConstantsMessage.MSG_REDIRECT_URL);
    }
    if (env.tokenInterval) {
      interval = parseInt(env.tokenInterval);
    }
    if (env.tokenThreshold) {
      threshold = parseInt(env.tokenInterval);
    }
    if (env.cacheLoc) {
      cacheLoc = BrowserCacheLocation[env.cacheLoc];
    }
    setOptions({
      scopes: env.scopes?.split(Constants.SPLIT_COMMA),
      tokenInterval: interval,
      tokenThreshold: threshold
    });
    const defaultConfig = {
      auth: {
        clientId: env.clientId,
        authority: env.authority,
        redirectUri: env.loginRedirectUri,
        postLogoutRedirectUri: env.logoutRedirectUri,
        navigateToLoginRequestUrl: false
      },
      cache: {
        cacheLocation: cacheLoc,
        storeAuthStateInCookie: true
      },
      system: {
        tokenRenewalOffsetSeconds: Constants.TOKEN_THRESHOLD
      }
    };
    return defaultConfig;
  };
  return { config, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
import React, { useEffect as useEffect2 } from "react";

// src/hooks/useUserAccount.ts
import { useContext } from "react";
import { useMsal } from "@azure/msal-react";
import { InteractionRequiredAuthError } from "@azure/msal-browser";
import { jwtDecode } from "jwt-decode";
import { useUserClaimService, useUserTokenService, useUserService, useAPITokenService } from "unw.react.framework.user.identity";

// src/context/AuthenticationContext.ts
import { createContext } from "react";
var AuthenticationContext = createContext(null);

// src/hooks/useUserAccount.ts
var useUserAccount = () => {
  const { instance, accounts } = useMsal();
  const authentication = useContext(AuthenticationContext);
  const { setUserToken, getTokenInfo } = useUserTokenService();
  const { getAPIServiceTokenInfo, setAPIServiceToken } = useAPITokenService();
  const { setUserClaims } = useUserClaimService();
  const { setUserInfo } = useUserService();
  const getUserToken = async () => {
    const token = getTokenInfo();
    if (token && !isTokenExpired(0, token)) {
      return token;
    }
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
    }
    return accountInfo?.accessToken;
  };
  const getServiceApiAccessToken = async (key) => {
    const apiServiceToken = getAPIServiceTokenInfo(key);
    if (apiServiceToken && apiServiceToken != null) {
      if (!isTokenExpired(0, apiServiceToken.refreshToken)) {
        return apiServiceToken.refreshToken;
      } else if (!isTokenExpired(0, apiServiceToken.accessToken)) {
        return apiServiceToken.accessToken;
      }
    }
    const tokenInfo = await getApiTokenInfo(key);
    if (tokenInfo) {
      const sharePointToken = [
        {
          tokenId: key,
          refreshToken: tokenInfo.access_token,
          accessToken: tokenInfo.access_token,
          tokenExpirationDate: tokenInfo.expires_on.toLocaleString()
        }
      ];
      setAPIServiceToken(sharePointToken);
      return tokenInfo.access_token;
    }
    return null;
  };
  const getApiTokenInfo = async (key) => {
    const envKey = key.toUpperCase();
    const apiAccessUrl = getEnvironmentValue(envKey + Constants.MIDDLEWARE_URL);
    const middlewareKey = getEnvironmentValue(envKey + Constants.MIDDLEWARE_KEY);
    const response = await fetch(apiAccessUrl, {
      method: "GET",
      headers: {
        "X-Middleware-Key": middlewareKey
      }
    });
    return response.json();
  };
  const setClaims = async (userClaims) => {
    if (userClaims && userClaims.length > 0) {
      setUserClaims(userClaims);
    }
  };
  const getAcquireTokenSilent = async (scopes) => {
    const authRequest = { account: accounts[0], scopes: Constants.SCOPES };
    if (scopes != null && scopes.length > 0) {
      authRequest.scopes = scopes;
    }
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
      setAccessTokenToStore(accountInfo);
    }
  };
  const setUserTokenToStore = (accountInfo) => {
    if (accountInfo) {
      const userToken = {
        tokenId: accountInfo.account?.localAccountId,
        idToken: accountInfo.account?.idToken,
        accessToken: accountInfo.accessToken,
        refreshToken: accountInfo.accessToken,
        tokenExpirationDate: accountInfo.expiresOn.toLocaleString()
      };
      setUserToken(userToken);
    }
  };
  const setAccessTokenToStore = (accountInfo) => {
    const accessToken = accountInfo.accessToken;
    if (accessToken) {
      const decodeToken = jwtDecode(accessToken);
      if (decodeToken) {
        const user = {
          name: decodeToken.name,
          firstname: decodeToken.given_name,
          lastName: decodeToken.family_name,
          email: accountInfo.username,
          upn: decodeToken.upn,
          guid: decodeToken.oid
        };
        setUserInfo(user);
      }
    }
  };
  const setAcquireTokenToStore = async () => {
    const scopes = authentication?.option?.scopes;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      setAccountInfoToStore(accountInfo);
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
    await setAcquireTokenToStore();
    setRefreshTokenInterval();
  };
  const setRefreshTokenInterval = () => {
    const option = authentication?.option;
    const threshold = option?.tokenThreshold ?? Constants.TOKEN_THRESHOLD;
    const interval = option?.tokenInterval ?? Constants.TOKEN_INTERVAL;
    setInterval(() => {
      const token = getTokenInfo();
      if (token === void 0 || isTokenExpired(threshold, token)) {
        setAcquireTokenToStore();
      }
    }, interval);
  };
  const isTokenExpired = (tokenThreshold, token) => {
    let isExpired = false;
    if (token && token != null) {
      const decodeToken = jwtDecode(token);
      if (decodeToken.exp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = decodeToken.exp - currentTime;
        isExpired = timeUntilExpiry <= (tokenThreshold ?? 0);
      }
    }
    return isExpired;
  };
  return { getUserToken, getServiceApiAccessToken, setUserActiveAccount, setClaims };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children }) => {
  const { setUserActiveAccount } = useUserAccount_default();
  useEffect2(() => {
    setUserActiveAccount();
  }, []);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ React2.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ React2.createElement(MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ React2.createElement(AuthenticatedTemplate, null, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, null, children))) : /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: InteractionType.Redirect }, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, null, children))))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
import { useMsal as useMsal2 } from "@azure/msal-react";
var useMsalAuthentication = () => {
  const { instance } = useMsal2();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
import { useIsAuthenticated } from "@azure/msal-react";
var useAuthenticated = () => {
  const isAuthenticated = useIsAuthenticated();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
export {
  AuthenticationProvider_default as AuthenticationProvider,
  useUserAccount_default as useAccount,
  useAuthenticated_default as useAuthenticated,
  useMsalAuthentication_default as useAuthentication
};
